==> jc-1.4.0.tar.gz: soot/options/FRWOptions.h <==
// public class soot.options.FRWOptions

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a2c93e5642f1e84 soot_options_FRWOptions

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_options_FRWOptions_H_
#define _JC_soot_options_FRWOptions_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_soot_options_FRWOptions$sub_refs	_jc_soot_options_FRWOptions$sub_refs;
typedef struct _jc_soot_options_FRWOptions$sub_nonrefs	_jc_soot_options_FRWOptions$sub_nonrefs;
typedef struct _jc_soot_options_FRWOptions$refs	_jc_soot_options_FRWOptions$refs;
typedef struct _jc_soot_options_FRWOptions$nonrefs	_jc_soot_options_FRWOptions$nonrefs;
typedef struct _jc_soot_options_FRWOptions$object	_jc_soot_options_FRWOptions$object;

typedef const struct _jc_soot_options_FRWOptions$vmethods	_jc_soot_options_FRWOptions$vmethods;
typedef const struct _jc_soot_options_FRWOptions$vtable	_jc_soot_options_FRWOptions$vtable;
typedef const struct _jc_soot_options_FRWOptions$vtype	_jc_soot_options_FRWOptions$vtype;

// Constructors
extern void _jc_soot_options_FRWOptions$method$_init$39bc1e191d75104e(_jc_env *, struct _jc_soot_options_FRWOptions$object *, struct _jc_object *);

// Virtual methods
extern jboolean _jc_soot_options_FRWOptions$method$enabled$e29aaa88d18be18b(_jc_env *, struct _jc_soot_options_FRWOptions$object *);
extern jint _jc_soot_options_FRWOptions$method$threshold$c0b57c14326841ce(_jc_env *, struct _jc_soot_options_FRWOptions$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_options_FRWOptions$method_info$enabled$e29aaa88d18be18b;
extern _jc_method _jc_soot_options_FRWOptions$method_info$threshold$c0b57c14326841ce;

// Virtual methods structure
struct _jc_soot_options_FRWOptions$vmethods {
	jboolean	(*enabled$e29aaa88d18be18b)(_jc_env *, struct _jc_soot_options_FRWOptions$object *);
	jint	(*threshold$c0b57c14326841ce)(_jc_env *, struct _jc_soot_options_FRWOptions$object *);
};

// Vtable
struct _jc_soot_options_FRWOptions$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_options_FRWOptions$vmethods	soot_options_FRWOptions;
};

// Vtype
struct _jc_soot_options_FRWOptions$vtype {
	_jc_type			type;
	_jc_soot_options_FRWOptions$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_options_FRWOptions$sub_refs {
	struct _jc_object	*options;
};

// Reference instance fields (object)
struct _jc_soot_options_FRWOptions$refs {
    _jc_soot_options_FRWOptions$sub_refs	soot_options_FRWOptions;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_options_FRWOptions$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_options_FRWOptions$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_options_FRWOptions$sub_nonrefs	soot_options_FRWOptions;
};

// Object instance structure
struct _jc_soot_options_FRWOptions$object {
	_jc_soot_options_FRWOptions$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_options_FRWOptions$vtype	*vtype;
	_jc_soot_options_FRWOptions$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_options_FRWOptions$vtype _jc_soot_options_FRWOptions$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_options_FRWOptions, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_options_FRWOptions$class_object;

#endif	/* _JC_soot_options_FRWOptions_H_ */

==> jc-1.4.6.tar.gz: soot/options/FRWOptions.h <==
// public class soot.options.FRWOptions

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a2c93e5642f1e84 soot_options_FRWOptions

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_options_FRWOptions_H_
#define _JC_soot_options_FRWOptions_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_soot_options_FRWOptions$sub_refs	_jc_soot_options_FRWOptions$sub_refs;
typedef struct _jc_soot_options_FRWOptions$sub_nonrefs	_jc_soot_options_FRWOptions$sub_nonrefs;
typedef struct _jc_soot_options_FRWOptions$refs	_jc_soot_options_FRWOptions$refs;
typedef struct _jc_soot_options_FRWOptions$nonrefs	_jc_soot_options_FRWOptions$nonrefs;
typedef struct _jc_soot_options_FRWOptions$object	_jc_soot_options_FRWOptions$object;

typedef const struct _jc_soot_options_FRWOptions$vmethods	_jc_soot_options_FRWOptions$vmethods;
typedef const struct _jc_soot_options_FRWOptions$vtable	_jc_soot_options_FRWOptions$vtable;
typedef const struct _jc_soot_options_FRWOptions$vtype	_jc_soot_options_FRWOptions$vtype;

// Constructors
extern void _jc_soot_options_FRWOptions$method$_init$39bc1e191d75104e(_jc_env *, struct _jc_soot_options_FRWOptions$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_options_FRWOptions$method$enabled$e29aaa88d18be18b(_jc_env *, struct _jc_soot_options_FRWOptions$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_options_FRWOptions$method$threshold$c0b57c14326841ce(_jc_env *, struct _jc_soot_options_FRWOptions$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_options_FRWOptions$method_info$enabled$e29aaa88d18be18b;
extern _jc_method _jc_soot_options_FRWOptions$method_info$threshold$c0b57c14326841ce;

// Virtual methods structure
struct _jc_soot_options_FRWOptions$vmethods {
	jboolean	(*enabled$e29aaa88d18be18b)(_jc_env *, struct _jc_soot_options_FRWOptions$object *) _JC_JCNI_ATTR;
	jint	(*threshold$c0b57c14326841ce)(_jc_env *, struct _jc_soot_options_FRWOptions$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_options_FRWOptions$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_options_FRWOptions$vmethods	soot_options_FRWOptions;
};

// Vtype
struct _jc_soot_options_FRWOptions$vtype {
	_jc_type			type;
	_jc_soot_options_FRWOptions$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_options_FRWOptions$sub_refs {
	struct _jc_object	*options;
};

// Reference instance fields (object)
struct _jc_soot_options_FRWOptions$refs {
    _jc_soot_options_FRWOptions$sub_refs	soot_options_FRWOptions;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_options_FRWOptions$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_options_FRWOptions$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_options_FRWOptions$sub_nonrefs	soot_options_FRWOptions;
};

// Object instance structure
struct _jc_soot_options_FRWOptions$object {
	_jc_soot_options_FRWOptions$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_options_FRWOptions$vtype	*vtype;
	_jc_soot_options_FRWOptions$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_options_FRWOptions$vtype _jc_soot_options_FRWOptions$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_options_FRWOptions, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_options_FRWOptions$class_object;

#endif	/* _JC_soot_options_FRWOptions_H_ */
